EXPORTS
	?jni_lookup@@YAP6AXXZPBD@Z @ 1 NONAME ; void (*)(void) jni_lookup(char const *)
	?isAttributesFound@BTServiceRecordPopulator@bluetooth@java@@QAE_NXZ @ 2 NONAME ; bool java::bluetooth::BTServiceRecordPopulator::isAttributesFound(void)
	??0BluetoothClientConnection@bluetooth@java@@QAE@PAVCBluetoothSocket@@PAVBluetoothFunctionServer@12@@Z @ 3 NONAME ; java::bluetooth::BluetoothClientConnection::BluetoothClientConnection(class CBluetoothSocket *, class java::bluetooth::BluetoothFunctionServer *)
	?initializeRecordL@ServiceRecord@bluetooth@java@@QAEXHHAAVTUUID@@AAVTDesC8@@@Z @ 4 NONAME ; void java::bluetooth::ServiceRecord::initializeRecordL(int, int, class TUUID &, class TDesC8 &)
	?isAllowedSender@BtUrlParams@bluetooth@java@@QAE_NAAVHBufC16@@AA_N1@Z @ 5 NONAME ; bool java::bluetooth::BtUrlParams::isAllowedSender(class HBufC16 &, bool &, bool &)
	?getParamEncrypt@BtUrlParams@bluetooth@java@@QAE_NXZ @ 6 NONAME ; bool java::bluetooth::BtUrlParams::getParamEncrypt(void)
	?cleanup@ServiceRecord@bluetooth@java@@SAXAAPAV123@@Z @ 7 NONAME ; void java::bluetooth::ServiceRecord::cleanup(class java::bluetooth::ServiceRecord * &)
	??1BtUrlParams@bluetooth@java@@QAE@XZ @ 8 NONAME ; java::bluetooth::BtUrlParams::~BtUrlParams(void)
	?init@BluetoothClientConnection@bluetooth@java@@QAEHH@Z @ 9 NONAME ; int java::bluetooth::BluetoothClientConnection::init(int)
	?getParamTransmitMtu@BtUrlParams@bluetooth@java@@QAEHXZ @ 10 NONAME ; int java::bluetooth::BtUrlParams::getParamTransmitMtu(void)
	?attributeListStart@ServiceRecord@bluetooth@java@@QAEHHH@Z @ 11 NONAME ; int java::bluetooth::ServiceRecord::attributeListStart(int, int)
	?initializeRecord@ServiceRecord@bluetooth@java@@QAEHHHV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@0@Z @ 12 NONAME ; int java::bluetooth::ServiceRecord::initializeRecord(int, int, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >)
	?initialize@BluetoothClientConnection@bluetooth@java@@QAEXH_JHH@Z @ 13 NONAME ; void java::bluetooth::BluetoothClientConnection::initialize(int, long long, int, int)
	?getParamAuthorize@BtUrlParams@bluetooth@java@@QAE_NXZ @ 14 NONAME ; bool java::bluetooth::BtUrlParams::getParamAuthorize(void)
	?setAttributeInt@ServiceRecord@bluetooth@java@@QAEHHHAAVTDesC8@@@Z @ 15 NONAME ; int java::bluetooth::ServiceRecord::setAttributeInt(int, int, class TDesC8 &)
	?getParamAuthenticate@BtUrlParams@bluetooth@java@@QAE_NXZ @ 16 NONAME ; bool java::bluetooth::BtUrlParams::getParamAuthenticate(void)
	?setAttributeUrl@ServiceRecord@bluetooth@java@@QAEHHAAVTDesC8@@@Z @ 17 NONAME ; int java::bluetooth::ServiceRecord::setAttributeUrl(int, class TDesC8 &)
	??0BtUrlParams@bluetooth@java@@QAE@V?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@0@Z @ 18 NONAME ; java::bluetooth::BtUrlParams::BtUrlParams(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >)
	?registerCallback@BluetoothClientConnection@bluetooth@java@@QAEXPAUJNIEnv_@@PAV_jobject@@@Z @ 19 NONAME ; void java::bluetooth::BluetoothClientConnection::registerCallback(struct JNIEnv_ *, class _jobject *)
	?getSecurityProperty@BluetoothRemoteDevice@bluetooth@java@@SAHCAA_J@Z @ 20 NONAME ; int java::bluetooth::BluetoothRemoteDevice::getSecurityProperty(signed char, long long &)
	?restorePersistentRecord@ServiceRecord@bluetooth@java@@QAEHXZ @ 21 NONAME ; int java::bluetooth::ServiceRecord::restorePersistentRecord(void)
	??1BluetoothClientConnection@bluetooth@java@@QAE@XZ @ 22 NONAME ; java::bluetooth::BluetoothClientConnection::~BluetoothClientConnection(void)
	??1BTServiceRecordPopulator@bluetooth@java@@QAE@XZ @ 23 NONAME ; java::bluetooth::BTServiceRecordPopulator::~BTServiceRecordPopulator(void)
	?getParamMaster@BtUrlParams@bluetooth@java@@QAE_NXZ @ 24 NONAME ; bool java::bluetooth::BtUrlParams::getParamMaster(void)
	?completesUpdateRecord@ServiceRecord@bluetooth@java@@QAEXXZ @ 25 NONAME ; void java::bluetooth::ServiceRecord::completesUpdateRecord(void)
	?setAttributeBool@ServiceRecord@bluetooth@java@@QAEHHH@Z @ 26 NONAME ; int java::bluetooth::ServiceRecord::setAttributeBool(int, int)
	?attributeListEnd@ServiceRecord@bluetooth@java@@QAEHH@Z @ 27 NONAME ; int java::bluetooth::ServiceRecord::attributeListEnd(int)
	?New@BTServiceRecordPopulator@bluetooth@java@@SAPAV123@PAUJNIEnv_@@PAV_jobject@@@Z @ 28 NONAME ; class java::bluetooth::BTServiceRecordPopulator * java::bluetooth::BTServiceRecordPopulator::New(struct JNIEnv_ *, class _jobject *)
	?setAttributeUint@ServiceRecord@bluetooth@java@@QAEHHHAAVTDesC8@@@Z @ 29 NONAME ; int java::bluetooth::ServiceRecord::setAttributeUint(int, int, class TDesC8 &)
	?getBluetoothPlatformControl@BluetoothPlatformControl@bluetooth@java@@SAPAV123@XZ @ 30 NONAME ; class java::bluetooth::BluetoothPlatformControl * java::bluetooth::BluetoothPlatformControl::getBluetoothPlatformControl(void)
	?getParamName@BtUrlParams@bluetooth@java@@QAE?AV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@XZ @ 31 NONAME ; class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > java::bluetooth::BtUrlParams::getParamName(void)
	?available@BluetoothClientConnection@bluetooth@java@@QAEJXZ @ 32 NONAME ; long java::bluetooth::BluetoothClientConnection::available(void)
	?connect@BluetoothClientConnection@bluetooth@java@@QAEH_JH_N1HH@Z @ 33 NONAME ; int java::bluetooth::BluetoothClientConnection::connect(long long, int, bool, bool, int, int)
	?getParamReceiveMtu@BtUrlParams@bluetooth@java@@QAEHXZ @ 34 NONAME ; int java::bluetooth::BtUrlParams::getParamReceiveMtu(void)
	?setAttributeUUID@ServiceRecord@bluetooth@java@@QAEHHAAVTUUID@@@Z @ 35 NONAME ; int java::bluetooth::ServiceRecord::setAttributeUUID(int, class TUUID &)
	?NewL@BluetoothNameLookup@bluetooth@java@@SAPAV123@XZ @ 36 NONAME ; class java::bluetooth::BluetoothNameLookup * java::bluetooth::BluetoothNameLookup::NewL(void)
	?getServiceUuid@BtUrlParams@bluetooth@java@@QAE?AV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@XZ @ 37 NONAME ; class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > java::bluetooth::BtUrlParams::getServiceUuid(void)
	?initializeUpdateRecord@ServiceRecord@bluetooth@java@@QAEXH@Z @ 38 NONAME ; void java::bluetooth::ServiceRecord::initializeUpdateRecord(int)
	?close@BluetoothClientConnection@bluetooth@java@@QAEXXZ @ 39 NONAME ; void java::bluetooth::BluetoothClientConnection::close(void)
	?setAttributeString@ServiceRecord@bluetooth@java@@QAEHHAAVTDesC8@@@Z @ 40 NONAME ; int java::bluetooth::ServiceRecord::setAttributeString(int, class TDesC8 &)
	?receive@BluetoothClientConnection@bluetooth@java@@QAEHAAPAD@Z @ 41 NONAME ; int java::bluetooth::BluetoothClientConnection::receive(char * &)
	?send@BluetoothClientConnection@bluetooth@java@@QAEHPBDH@Z @ 42 NONAME ; int java::bluetooth::BluetoothClientConnection::send(char const *, int)
	?isBlockedSender@BtUrlParams@bluetooth@java@@QAE_NAAVHBufC16@@@Z @ 43 NONAME ; bool java::bluetooth::BtUrlParams::isBlockedSender(class HBufC16 &)
	?getServiceRecordID@ServiceRecord@bluetooth@java@@QAEHXZ @ 44 NONAME ; int java::bluetooth::ServiceRecord::getServiceRecordID(void)
	?getReceiveMTU@BluetoothClientConnection@bluetooth@java@@QAEHXZ @ 45 NONAME ; int java::bluetooth::BluetoothClientConnection::getReceiveMTU(void)
	?restoreJavaServiceRecordL@ServiceRecord@bluetooth@java@@QAEXPAUJNIEnv_@@PAV_jobject@@@Z @ 46 NONAME ; void java::bluetooth::ServiceRecord::restoreJavaServiceRecordL(struct JNIEnv_ *, class _jobject *)
	??0BluetoothClientConnection@bluetooth@java@@QAE@PAVBluetoothFunctionServer@12@@Z @ 47 NONAME ; java::bluetooth::BluetoothClientConnection::BluetoothClientConnection(class java::bluetooth::BluetoothFunctionServer *)
	?setDeviceServiceClass@ServiceClassHandler@bluetooth@java@@SAHI_N@Z @ 48 NONAME ; int java::bluetooth::ServiceClassHandler::setDeviceServiceClass(unsigned int, bool)
	?setAdvertiseFs@ServiceRecord@bluetooth@java@@QAEHH@Z @ 49 NONAME ; int java::bluetooth::ServiceRecord::setAdvertiseFs(int)
	?doDeviceNameLookupL@BluetoothNameLookup@bluetooth@java@@QAEPAV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@_J@Z @ 50 NONAME ; class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > * java::bluetooth::BluetoothNameLookup::doDeviceNameLookupL(long long)
	?getTransmitMTU@BluetoothClientConnection@bluetooth@java@@QAEHXZ @ 51 NONAME ; int java::bluetooth::BluetoothClientConnection::getTransmitMTU(void)
	?setAttributeNil@ServiceRecord@bluetooth@java@@QAEHH@Z @ 52 NONAME ; int java::bluetooth::ServiceRecord::setAttributeNil(int)
	?getProtocol@BtUrlParams@bluetooth@java@@QAE?AV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@XZ @ 53 NONAME ; class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > java::bluetooth::BtUrlParams::getProtocol(void)
	?NewL@ServiceRecord@bluetooth@java@@SAPAV123@PAVBluetoothFunctionServer@23@@Z @ 54 NONAME ; class java::bluetooth::ServiceRecord * java::bluetooth::ServiceRecord::NewL(class java::bluetooth::BluetoothFunctionServer *)
	?getSystemProperty@BluetoothPlatformControl@bluetooth@java@@SA?AV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@H@Z @ 55 NONAME ; class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > java::bluetooth::BluetoothPlatformControl::getSystemProperty(int)
	??1BluetoothNameLookup@bluetooth@java@@UAE@XZ @ 56 NONAME ; java::bluetooth::BluetoothNameLookup::~BluetoothNameLookup(void)
	?getRemoteAddress@BluetoothClientConnection@bluetooth@java@@QAE_JXZ @ 57 NONAME ; long long java::bluetooth::BluetoothClientConnection::getRemoteAddress(void)
	?getBluetoothDeviceClass@S60BluetoothPlatformControl@bluetooth@java@@UAEIAAH@Z @ 58 NONAME ; unsigned int java::bluetooth::S60BluetoothPlatformControl::getBluetoothDeviceClass(int &)

